@@ -46,6 +46,13 @@
 # define X_CST_PTR_CST_PTR_Y(x,y) x * const * y
 #endif /* !__cplusplus */
 
+#define NCO_ERR_FL_LN do {						\
+    (void)fflush(stdout); /* Synchronize stdout with stderr */		\
+    (void)fprintf(stderr, "Failure in NCO funcion in file %s at line %d\n",__FILE__,__LINE__); \
+    (void)fflush(stderr);						\
+    return 2;								\
+  } while (0)
+
 #ifdef __cplusplus
 /* Use C-bindings so C++-compiled and C-compiled libraries are compatible */
 extern "C" {
@@ -366,7 +373,7 @@ extern "C" {
 # define NCO_VERSION_MINOR 1
 #endif /* !NCO_VERSION_MINOR */
 #ifndef NCO_VERSION_PATCH
-# define NCO_VERSION_PATCH 3
+# define NCO_VERSION_PATCH 4
 #endif /* !NCO_VERSION_PATCH */
 #ifndef NCO_VERSION_NOTE
 # define NCO_VERSION_NOTE "" /* Blank for final versions, non-blank (e.g., "-beta37") for pre-release versions */
@@ -376,7 +383,7 @@ extern "C" {
 # define NCO_LIB_VERSION ( NCO_VERSION_MAJOR * 100 + NCO_VERSION_MINOR * 10 + NCO_VERSION_PATCH )
 #endif /* !NCO_LIB_VERSION */
 #ifndef NCO_VERSION
-# define NCO_VERSION "5.1.3"
+# define NCO_VERSION "5.1.4"
 #endif /* !NCO_VERSION */
 
 /* Compatibility tokens new to netCDF4 netcdf.h: */
@@ -1185,11 +1192,15 @@ typedef enum nco_xtr_typ_enm
     char *bnd_tm_nm; /* [sng] Name of dimension to employ for temporal bounds */
     char *col_nm_in; /* [sng] Name to recognize as input horizontal spatial dimension on unstructured grid */
     char *col_nm_out; /* [sng] Name of horizontal spatial output dimension on unstructured grid */
+    char *dpt_nm_in; /* [sng] Name of input variable to recognize as depth for depth/height grids */
+    char *dpt_nm_out; /* [sng] Name of variable to output as depth for depth/height grids */
+    char *dpt_nm_tpl; /* [sng] Name of template variable to recognize as depth for depth/height grids */
     char *fl_hnt_dst; /* [sng] ERWG hint destination */
     char *fl_hnt_src; /* [sng] ERWG hint source */
     char *frc_nm; /* [sng] Name of variable containing gridcell fraction */
     char *ilev_nm_in; /* [sng] Name of input dimension to recognize as vertical dimension at layer interfaces */
     char *ilev_nm_out; /* [sng] Name of output vertical dimension at layer interfaces */
+    char *ilev_nm_tpl; /* [sng] Name of template vertical dimension at layer interfaces */
     char *lat_bnd_nm; /* [sng] Name of rectangular boundary variable for latitude */
     char *lat_dmn_nm; /* [sng] Name of latitude dimension in inferred grid */
     char *lat_nm_in; /* [sng] Name of input dimension to recognize as latitude */
@@ -1198,6 +1209,7 @@ typedef enum nco_xtr_typ_enm
     char *lat_wgt_nm; /* [sng] Name of variable containing latitude weights */
     char *lev_nm_in; /* [sng] Name of input dimension to recognize as vertical dimension at layer midpoints */
     char *lev_nm_out; /* [sng] Name of output vertical dimension at layer midpoints */
+    char *lev_nm_tpl; /* [sng] Name of template vertical dimension at layer midpoints */
     char *lon_bnd_nm; /* [sng] Name of rectangular boundary variable for longitude */
     char *lon_dmn_nm; /* [sng] Name of longitude dimension in inferred grid */
     char *lon_nm_in; /* [sng] Name of dimension to recognize as longitude */
