@@ -75,8 +75,7 @@ nco_cnv_arm_time_mk /* [fnc] Return time corresponding to current time offset */
 void
 nco_cnv_arm_time_install /* [fnc] Add time variable to concatenated ARM files */
 (const int nc_id, /* I [id] netCDF file ID */
- const nco_int base_time_srt, /* I [s] base_time of first input file */
- const int dfl_lvl) /* I [enm] Deflate level [0..9] */
+ const nco_int base_time_srt) /* I [s] base_time of first input file */
 {
   /* NB: nco_cnv_arm_time_install() contains OpenMP critical region */
   /* Purpose: Add time variable to concatenated ARM files */
@@ -120,7 +119,7 @@ nco_cnv_arm_time_install /* [fnc] Add time variable to concatenated ARM files */
   if(rcd != NC_NOERR){
     (void)fprintf(stderr,"%s: WARNING ARM file does not have dimension \"time\"\n",nco_prg_nm_get());
     return;
-  } /* endif */
+  } /* !rcd */
   /* Get dimension size */
   (void)nco_inq_dimlen(nc_id,time_dmn_id,&cnt);
 
@@ -139,7 +138,13 @@ nco_cnv_arm_time_install /* [fnc] Add time variable to concatenated ARM files */
   (void)nco_def_var(nc_id,time_sng,NC_DOUBLE,1,&time_dmn_id,&time_id);
 
   /* Set HDF Lempel-Ziv compression level, if requested */
-  if(dfl_lvl >= 0) (void)nco_def_var_deflate(nc_id,time_id,(int)NC_SHUFFLE,(int)True,dfl_lvl);
+  //if(dfl_lvl >= 0) (void)nco_def_var_deflate(nc_id,time_id,(int)NC_SHUFFLE,(int)True,dfl_lvl);
+  if(nco_cmp_glb_get()) rcd=nco_flt_def_out(nc_id,time_id,NULL,nco_flt_flg_prc_fll);
+  if(rcd != NC_NOERR){
+    (void)fprintf(stderr,"%s: WARNING ARM file could not compress \"time\" variable\n",nco_prg_nm_get());
+    rcd=NC_NOERR;
+    return;
+  } /* !rcd */
 
   /* Add attributes for time variable */
   (void)nco_put_att(nc_id,time_id,units_sng,NC_CHAR,(long int)(strlen(att_units)+1UL),(const void *)att_units);
@@ -161,7 +166,7 @@ nco_cnv_arm_time_install /* [fnc] Add time variable to concatenated ARM files */
   time_offset=(double *)nco_free(time_offset);
 
   return; /* 20050109: fxm added return to void function to squelch erroneous gcc-3.4.2 warning */ 
-} /* end nco_cnv_arm_time_install */
+} /* !nco_cnv_arm_time_install */
 
 nco_int /* O [s] Value of base_time variable */
 nco_cnv_arm_base_time_get /* [fnc] Get base_time variable from ARM file */
