@@ -121,6 +121,11 @@ nco_cnv_ini /* O [fnc] Determine conventions (ARM/CCM/CCSM/CF/MPAS) for treating
 
   /* Allocate */
   cnv=(cnv_sct *)nco_malloc(sizeof(cnv_sct));
+  /* Set defaults */
+  cnv->CCM_CCSM_CF=False;
+  cnv->MPAS=False;
+  cnv->Group=False;
+  cnv->cf_vrs=1.0;
     
   /* Look for signature of a CCM/CCSM/CF-format file */
   cnv_sng=cnv_sng_UC;
@@ -143,7 +148,14 @@ nco_cnv_ini /* O [fnc] Determine conventions (ARM/CCM/CCSM/CF/MPAS) for treating
     if(strstr(att_val,"CF-1.")) cnv->CCM_CCSM_CF=True; /* NB: Not fully implemented TODO nco145 */
     /* As of 20060514, CLM 3.0 uses CF1.0 not CF-1.0 (CAM gets it right) */
     if(strstr(att_val,"CF1.")) cnv->CCM_CCSM_CF=True; /* NB: Not fully implemented TODO nco145 */
-    if(strstr(att_val,"MPAS")) cnv->MPAS=True; /* This works for all known MPAS versions */
+    if(strstr(att_val,"MPAS")) cnv->MPAS=True; /* This works for MPAS v1 data */
+    /* 20221215 For MPAS v2 data, use model_name attribute */
+    char *att_cnv_val=NULL;
+    char att_sng_cnv[]="model_name"; /* [sng] Global attribute in MPAS v1, v2 datasets */
+    att_cnv_val=nco_char_att_get(nc_id,NC_GLOBAL,att_sng_cnv);
+    if(att_cnv_val && strstr(att_cnv_val,"mpas")) cnv->MPAS=True;
+    if(att_cnv_val) att_cnv_val=(char *)nco_free(att_cnv_val);
+   
     if(strstr(att_val,"Group")) cnv->Group=True; /* Untested */
     cnv->cf_vrs=1.0; /* Untested */
     if(nco_dbg_lvl_get() >= nco_dbg_scl && (cnv->CCM_CCSM_CF || cnv->MPAS)){
@@ -151,13 +163,13 @@ nco_cnv_ini /* O [fnc] Determine conventions (ARM/CCM/CCSM/CF/MPAS) for treating
       if(cnv_sng == cnv_sng_LC) (void)fprintf(stderr,"%s: WARNING: This file uses a non-standard attribute (\"%s\") to indicate the netCDF convention. The correct attribute is \"%s\".\n",nco_prg_nm_get(),cnv_sng_LC,cnv_sng_UC);
       /* Only warn in arithmetic operators where conventions change behavior */
       if(nco_dbg_lvl_get() >= nco_dbg_fl && nco_dbg_lvl_get() != nco_dbg_dev && nco_is_rth_opr(nco_prg_id_get())) (void)fprintf(stderr,"%s: INFO NCO attempts to abide by many official and unofficial metadata conventions including ARM, CCM, CCSM, CF, and MPAS. To adhere to these conventions, NCO implements variable-specific exceptions in certain operators, e.g., ncbo will not subtract variables named \"date\" or \"gw\" (for CCM/CCSM files) or \"areaCell\" or \"edgesOnCell\" (for MPAS files), and many operators will always leave coordinate variables unchanged. The full list of exceptions is in the manual http://nco.sf.net/nco.html#CF\n",nco_prg_nm_get());
-    } /* endif dbg */
+    } /* !dbg */
     att_val=(char *)nco_free(att_val);
   } /* endif */
 
   return cnv;
   
-} /* end nco_cnv_ini() */
+} /* !nco_cnv_ini() */
 
 nco_bool /* O [flg] File obeys CCM/CCSM/CF conventions */
 nco_cnv_ccm_ccsm_cf_inq /* O [fnc] Check if file obeys CCM/CCSM/CF conventions */
@@ -206,7 +218,7 @@ nco_cnv_ccm_ccsm_cf_inq /* O [fnc] Check if file obeys CCM/CCSM/CF conventions *
       if(cnv_sng == cnv_sng_LC) (void)fprintf(stderr,"%s: WARNING: This file uses a non-standard attribute (\"%s\") to indicate the netCDF convention. The correct attribute is \"%s\".\n",nco_prg_nm_get(),cnv_sng_LC,cnv_sng_UC);
       /* Only warn in arithmetic operators where conventions change behavior */
       if(nco_dbg_lvl_get() >= nco_dbg_fl && nco_dbg_lvl_get() != nco_dbg_dev && nco_is_rth_opr(nco_prg_id_get())) (void)fprintf(stderr,"%s: INFO NCO attempts to abide by many official and unofficial metadata conventions including ARM, CCM, CCSM, and CF. To adhere to these conventions, NCO implements variable-specific exceptions in certain operators, e.g., ncbo will not subtract variables named \"date\" or \"gw\", and many operators will always leave coordinate variables unchanged. The full list of exceptions is in the manual http://nco.sf.net/nco.html#CF\n",nco_prg_nm_get());
-    } /* endif dbg */
+    } /* !dbg */
     att_val=(char *)nco_free(att_val);
   } /* endif */
 
