@@ -49,7 +49,7 @@
 /* 3rd party vendors */
 #include <netcdf.h> /* netCDF definitions and C library */
 #ifdef NC_HAVE_META_H
-# include <netcdf_meta.h> /* NC_VERSION_..., HAVE_NC_RENAME_GRP */	 
+# include <netcdf_meta.h> /* NC_VERSION_..., NC_HAS_QUANTIZE, NC_HAS_ZSTD */
 #endif /* !NC_HAVE_META_H */
 #ifndef NC_LIB_VERSION
 # define NC_LIB_VERSION ( NC_VERSION_MAJOR * 100 + NC_VERSION_MINOR * 10 + NC_VERSION_PATCH )
@@ -124,8 +124,14 @@
 #ifndef NC_NOCHECKSUM
 # define NC_NOCHECKSUM 0
 #endif
+#ifndef NC_FLETCHER32
+# define NC_FLETCHER32 1
+#endif
 #ifndef NC_NOSHUFFLE
 # define NC_NOSHUFFLE 0
+#endif
+#ifndef NC_SHUFFLE
+# define NC_SHUFFLE   1
 #endif
 
   /* 20131222: Seven compatibility tokens introduced in netCDF 4.3.1-rc7 netcdf.h
@@ -185,6 +191,9 @@
 #ifndef NC_FORMATX_DAP4
 # define NC_FORMATX_DAP4    (6)
 #endif
+#ifndef NC_FORMATX_NCZARR
+# define NC_FORMATX_NCZARR  (10)
+#endif
 
 /* Three compatibility tokens from pnetcdf.h introduced to NCO 20140604 
    First actually used 20160114 */
@@ -270,6 +279,32 @@
 # define NC_EFILLVALUE    (-122)    /**< Attempt to define fill value when data already exists. */
 #endif /* !HAVE_NETCDF4_H */
 
+/* Filter tokens introduced in netcdf_filter.h 4.9.0 ~202206
+   Some of these are needed by nc_filter_avail() stub */
+/* Must match values in <H5Zpublic.h> */
+#ifndef H5Z_FILTER_DEFLATE
+# define H5Z_FILTER_DEFLATE 1
+#endif
+#ifndef H5Z_FILTER_SHUFFLE
+# define H5Z_FILTER_SHUFFLE 2
+#endif
+#ifndef H5Z_FILTER_FLETCHER32
+# define H5Z_FILTER_FLETCHER32 3
+#endif
+#ifndef H5Z_FILTER_SZIP
+# define H5Z_FILTER_SZIP 4
+#endif
+/* Other Standard Filters */
+#ifndef H5Z_FILTER_ZSTD
+# define H5Z_FILTER_ZSTD 32015
+#endif
+#ifndef H5Z_FILTER_BZIP2
+# define H5Z_FILTER_BZIP2 307
+#endif
+#ifndef H5Z_FILTER_BLOSC
+# define H5Z_FILTER_BLOSC 32001
+#endif
+
 /* define MAX CHUNK SIZE here as its not present in netcdf.h */
 #define NCO_MAX_CHUNK_SIZE (0xFFFFFFFF)
 
@@ -521,6 +556,8 @@ int nco_inq_var_filter(const int nc_id,const int var_id,unsigned int * const flt
 int nco_inq_var_filter_flg(const int nc_id,const int var_id,unsigned int * const flt_id,size_t * const prm_nbr,unsigned int * const prm_lst);
 int nco_inq_var_filter_ids(const int nc_id,const int var_id,size_t * const flt_nbr,unsigned int * const flt_lst);
 int nco_inq_var_filter_info(const int nc_id,const int var_id,const unsigned int flt_id,size_t * const prm_nbr,unsigned int * const prm_lst);
+int nco_inq_filter_avail(const int nc_id,const unsigned int flt_id);
+int nco_inq_filter_avail_flg(const int nc_id,const unsigned int flt_id);
 int nco_inq_var_fletcher32(const int nc_id,const int var_id,int * const chk_typ);
 int nco_inq_var_packing(const int nc_id,const int var_id,int * const packing);
 int nco_inq_vardimid(const int nc_id,const int var_id,int * const dmn_id);
@@ -563,9 +600,10 @@ int nco_get_att(const int nc_id,const int var_id,const char * const att_nm,void
 /* End Attribute routines */
 
 /* Begin libnetcdf prototypes (i.e., for completely new library routines not yet in netcdf.h */
-#ifndef HAVE_NC_RENAME_GRP
+/* NC_HAVE_RENAME_GRP replaced HAVE_NC_RENAME_GRP in netCDF 4.9.0 */ 
+#if !defined(NC_HAVE_RENAME_GRP) && !defined(HAVE_NC_RENAME_GRP)
   int nc_rename_grp(int grp_id,const char * const grp_nm);
-#endif /* HAVE_NC_RENAME_GRP */
+#endif /* NC_HAVE_RENAME_GRP */
   /* nc_open_mem() is defined in netCDF >= 4.4.0, however ...
      Ubuntu (Xenial at least) used broken netCDF CMake (not autoconf) to package 4.4.0, and it does not install netcdf_mem.h:
      https://github.com/nco/nco/issues/44
@@ -591,27 +629,32 @@ int nco_get_att(const int nc_id,const int var_id,const char * const att_nm,void
   int nc_create_mem(const char * const fl_nm,const int mode,const size_t sz_ntl,int * const nc_id);
   int nc_open_memio(const char * const fl_nm,const int mode,NC_memio * const info,int * const nc_id);
   int nc_close_memio(const int nc_id,NC_memio * const info);
-#endif /* !4.6.2 */
+#endif /* !462, !4.6.2 */
 
 #if NC_LIB_VERSION < 460
   int nc_def_var_filter(const int nc_id,const int var_id,const unsigned int flt_id,const size_t prm_nbr,const unsigned int * const prm_lst);
   int nc_inq_var_filter(const int nc_id,const int var_id,unsigned int * const flt_id,size_t * const prm_nbr,unsigned int * const prm_lst);
-#endif /* !4.6.0 */
+#endif /* !460, !4.6.0 */
 
 #if NC_LIB_VERSION == 474
 # define nc_inq_var_filter_ids nc_inq_var_filterids
-#endif /* !4.7.4 */
+#endif /* !474, !4.7.4 */
 #if NC_LIB_VERSION < 474
   int nc_inq_var_filter_ids(const int nc_id,const int var_id,size_t * const flt_nbr,unsigned int * const flt_lst);
   int nc_inq_var_filter_info(const int nc_id,const int var_id,const unsigned int flt_id,size_t * const prm_nbr,unsigned int * const prm_lst);
-#endif /* !4.7.4 */
+#endif /* !474, !4.7.4 */
+#if NC_LIB_VERSION < 490
+  int nc_inq_filter_avail(const int nc_id,const unsigned int flt_id);
+  int nc_def_var_quantize(int nc_id,int var_id,int qnt_md,int nsd);
+  int nc_inq_var_quantize(int nc_id,int var_id,int *qnt_md,int *nsdp);
+#endif /* !490, !4.9.0 */
 
   int nc_def_var_filter_ccr(const int nc_id,const int var_id,const char * const flt_nm,const size_t prm_nbr,const char ** const prm_lst);
 
   /* Begin netCDF4 stubs */
 #ifndef HAVE_NETCDF4_H
   /* Stubs so netCDF4 functions work without protection in netCDF3 environments */
-# ifdef NC_HAVE_NEW_CHUNKING_API
+# if defined(NC_HAVE_NEW_CHUNKING_API) || defined(HAVE_NEW_CHUNKING_API)
   /* Newer, post-200906 netCDF4 API has chk_sz as const
      netcdf.h signals this API with NC_HAVE_NEW_CHUNKING_API as of ~200911 */
   int nc_def_var_chunking(const int nc_id,const int var_id,const int srg_typ,const size_t * const cnk_sz);
