@@ -5,7 +5,7 @@
 /* Copyright (C) 2019--present Charlie Zender
    This file is part of NCO, the netCDF Operators. NCO is free software.
    You may redistribute and/or modify NCO under the terms of the 
-   GNU General Public License (GPL) Version 3 with exceptions described in the LICENSE file */
+   3-Clause BSD License with exceptions described in the LICENSE file */
 
 #include "nco_ply.h" /* Polygon structure & utilities */
 
@@ -53,6 +53,9 @@ nco_poly_free
 }  
 
 
+
+
+
 poly_sct *   
 nco_poly_init
 (void)
@@ -77,8 +80,8 @@ nco_poly_init
   pl->dp_y_minmax[0]=0.0;
   pl->dp_y_minmax[1]=0.0;
 
-  pl->dp_x_ctr=DBL_MAX;
-  pl->dp_y_ctr=DBL_MAX;
+  pl->dp_x_ctr=KD_DBL_MAX;
+  pl->dp_y_ctr=KD_DBL_MAX;
 
   pl->wgt=0.0;
   pl->stat=0;
@@ -177,7 +180,40 @@ nco_poly_dpl
   return pl_cpy;
   
 } 
-  
+
+size_t
+nco_poly_sizeof(poly_sct *pl)
+{
+
+  size_t ttl_sz=0;
+  size_t arr_sz;
+
+  if(!pl)
+    return ttl_sz;
+
+
+  ttl_sz=sizeof(poly_sct);
+
+
+
+  if(pl->crn_nbr==0)
+    return ttl_sz;
+
+  arr_sz=sizeof(double)*pl->crn_nbr;
+
+  if(pl->dp_x)ttl_sz+=arr_sz;
+
+  if(pl->dp_y)ttl_sz+=arr_sz;
+
+  if(pl->shp)ttl_sz+=arr_sz*3;
+
+  if(pl->dp_xyz)ttl_sz+=arr_sz;
+
+  return ttl_sz;
+
+
+}
+
 poly_sct *
 nco_poly_init_crn
 (poly_typ_enm pl_typ,
@@ -361,11 +397,11 @@ void nco_poly_minmax_add
 
   sz=pl->crn_nbr;
 
-  pl->dp_x_minmax[0]=DBL_MAX;
-  pl->dp_x_minmax[1]=-DBL_MAX;
+  pl->dp_x_minmax[0]=KD_DBL_MAX;
+  pl->dp_x_minmax[1]=-KD_DBL_MAX;
 
-  pl->dp_y_minmax[0]=DBL_MAX;
-  pl->dp_y_minmax[1]=-DBL_MAX;
+  pl->dp_y_minmax[0]=KD_DBL_MAX;
+  pl->dp_y_minmax[1]=-KD_DBL_MAX;
 
 
 
@@ -513,8 +549,8 @@ void nco_poly_minmax_add
           case nco_grd_lon_Grn_ctr:
             nco_msh_lon_crr(lcl_dp_x, sz, 1, grd_lon_typ, nco_grd_lon_180_ctr);
 
-            pl->dp_x_minmax[0] = DBL_MAX;
-            pl->dp_x_minmax[1] = -DBL_MAX;
+            pl->dp_x_minmax[0] = KD_DBL_MAX;
+            pl->dp_x_minmax[1] = -KD_DBL_MAX;
 
             /* find new min-max */
             for (idx = 0; idx < sz; idx++) {
@@ -534,8 +570,8 @@ void nco_poly_minmax_add
           case nco_grd_lon_180_wst:
           case nco_grd_lon_180_ctr:
             nco_msh_lon_crr(lcl_dp_x, sz, 1, grd_lon_typ, nco_grd_lon_Grn_ctr);
-            pl->dp_x_minmax[0] = DBL_MAX;
-            pl->dp_x_minmax[1] = -DBL_MAX;
+            pl->dp_x_minmax[0] = KD_DBL_MAX;
+            pl->dp_x_minmax[1] = -KD_DBL_MAX;
 
             /* find new min-max */
             for (idx = 0; idx < sz; idx++) {
@@ -551,7 +587,23 @@ void nco_poly_minmax_add
             break;
 
         }
-        /* swap values if necessaary */
+
+        /* max == 360.0 has been converted to 0.0 we want the 360 value for the limits *
+         * as the kd tree manages wrapping by splitting the limits into 2 *
+         * dont wish to edit the actual vertices */
+        if(grd_lon_typ == nco_grd_lon_Grn_wst || grd_lon_typ ==  nco_grd_lon_Grn_ctr)
+        {
+          if( pl->dp_x_minmax[0] == 0.0 &&  pl->dp_x_minmax[1] >180.0   )
+            pl->dp_x_minmax[0]=360.0;
+
+          else if( pl->dp_x_minmax[0] >180.0  &&  pl->dp_x_minmax[1] == 0.0 )
+            pl->dp_x_minmax[1]=360.0;
+
+        }
+
+
+
+        /* swap values if necessasary */
         if (pl->dp_x_minmax[0] > pl->dp_x_minmax[1]) {
           double stmp;
           stmp = pl->dp_x_minmax[0];
@@ -562,9 +614,13 @@ void nco_poly_minmax_add
         }
 
 
-        lcl_dp_x = (double *) nco_free(lcl_dp_x);
+       /* double check wrapping again */
+       if(pl->dp_x_minmax[1] - pl->dp_x_minmax[0] < 180.0)
+         pl->bwrp=False;
 
 
+        lcl_dp_x = (double *) nco_free(lcl_dp_x);
+
       }
 
       /* nb no need to add correction for Rll grid */
@@ -587,51 +643,6 @@ void nco_poly_minmax_add
 }
 
 
-
-void
-nco_poly_area_add(
-poly_sct *pl){
-
-  if(pl->crn_nbr <3)
-    pl->area=0.0;
-
-
-  if(pl->pl_typ == poly_sph )
-  {
-    nco_msh_plg_area(pl->dp_y, pl->dp_x, 1, pl->crn_nbr, &pl->area);
-
-    /* charlies function can sometimes return a NaN */
-    if (isnan(pl->area))
-      pl->area = 0.0;
-
-  }
-
-  /* rll poly polygon should only have 3 or 4 vertex */
-  if(pl->pl_typ == poly_rll){
-    /* full formula area=(lon1-lon0)*(sin(lat1)-sin(lat0) ) */
-    double dp_tmp=sin(D2R( pl->dp_y_minmax[1] )) - sin(D2R(pl->dp_y_minmax[0]) );
-
-    double dff=pl->dp_x_minmax[1] - pl->dp_x_minmax[0];
-
-    if(pl->bwrp )
-      dp_tmp *= D2R(360.0 - dff );
-    else
-      dp_tmp*=D2R(dff);
-
-
-    pl->area = fabs(dp_tmp);
-
-
-
-  }
-    //nco_rll_area(pl);
-
-
-
-}
-
-
-
 /* Uses min-max limits only no serious polygon stuff */
 /* should really only be used after nco_sph_intersect */
 /* remember that for polY_sph - dp_y_minmax[0,1] a latitude correction has been added */
@@ -1099,7 +1110,7 @@ double *lcl_dp_y)
   
   int lcl_min=0;
   int crn_nbr=pl->crn_nbr;
-  double x_min=DBL_MAX;
+  double x_min=KD_DBL_MAX;
 
     
   /* find index of min X value */
@@ -1274,7 +1285,6 @@ poly_sct *pl
     for (idx = 0; idx < pl->crn_nbr; idx++)
       nco_geo_sph_2_lonlat(pl->shp[idx], &pl->dp_x[idx], &pl->dp_y[idx], bDeg);
 
-
   }
 
   /* remember RLL intersection uses lon/lat so use these values */
@@ -1377,10 +1387,10 @@ nco_grd_lon_typ_enm
 nco_poly_minmax_2_lon_typ
 (poly_sct *pl)
 {
-  /* double lon_min=pl->dp_x_minmax[0]; */
+  double lon_min;
   double lon_max;
 
-
+  lon_min=pl->dp_x_minmax[0];
   lon_max=pl->dp_x_minmax[1];
 
   if( lon_max >180.0 )
@@ -1389,6 +1399,11 @@ nco_poly_minmax_2_lon_typ
   if(lon_max >0.0 && lon_max <=180.0 )
     return nco_grd_lon_180_ctr;
 
+  if( (lon_min >=-180.0 && lon_min<0.0) || (lon_max >=-180.0 && lon_max<0.0) )
+    return nco_grd_lon_180_ctr;
+
+
+
   return nco_grd_lon_nil;
 
 }
