@@ -91,7 +91,10 @@ nco_ppc_ini /* Set PPC based on user specifications */
 
   /* PPC "default" specified, set all non-coordinate variables to default first */
   for(ppc_var_idx=0;ppc_var_idx<ppc_var_nbr;ppc_var_idx++){
-    if(!strcasecmp(ppc_lst[ppc_var_idx].key,"default")){
+    if(!strcasecmp(ppc_lst[ppc_var_idx].key,"default") ||
+       !strcasecmp(ppc_lst[ppc_var_idx].key,"dfl") ||
+       !strcasecmp(ppc_lst[ppc_var_idx].key,"global") ||
+       !strcasecmp(ppc_lst[ppc_var_idx].key,"glb")){
       nco_ppc_set_dflt(nc_id,ppc_lst[ppc_var_idx].val,trv_tbl);
       break; /* Only one default is needed */
     } /* endif */
@@ -99,7 +102,10 @@ nco_ppc_ini /* Set PPC based on user specifications */
 
   /* Set explicit, non-default PPCs that can overwrite default */
   for(ppc_var_idx=0;ppc_var_idx<ppc_var_nbr;ppc_var_idx++){
-    if(!strcasecmp(ppc_lst[ppc_var_idx].key,"default")) continue;
+    if(!strcasecmp(ppc_lst[ppc_var_idx].key,"default") ||
+       !strcasecmp(ppc_lst[ppc_var_idx].key,"dfl") ||
+       !strcasecmp(ppc_lst[ppc_var_idx].key,"global") ||
+       !strcasecmp(ppc_lst[ppc_var_idx].key,"glb")) continue;
     nco_ppc_set_var(ppc_lst[ppc_var_idx].key,ppc_lst[ppc_var_idx].val,trv_tbl);
   } /* end for */
 
@@ -215,9 +221,7 @@ nco_ppc_set_dflt /* Set PPC value for all non-coordinate variables for --ppc def
 	int var_id;
 	nco_inq_grp_full_ncid(nc_id,trv_tbl->lst[idx_tbl].grp_nm_fll,&grp_id);
 	nco_inq_varid(grp_id,trv_tbl->lst[idx_tbl].nm,&var_id);
-	if(!nco_is_spc_in_cf_att(grp_id, "bounds", var_id, NULL) && !nco_is_spc_in_cf_att(grp_id, "climatology", var_id,
-                                                                                      NULL) && !nco_is_spc_in_cf_att(
-    grp_id, "coordinates", var_id, NULL)){
+	if(!nco_is_spc_in_cf_att(grp_id,"bounds",var_id,NULL) && !nco_is_spc_in_cf_att(grp_id,"climatology",var_id,NULL) && !nco_is_spc_in_cf_att(grp_id,"coordinates",var_id,NULL) && !nco_is_spc_in_cf_att(grp_id,"grid_mapping",var_id,NULL)){
 	  trv_tbl->lst[idx_tbl].ppc=ppc_val;
 	  trv_tbl->lst[idx_tbl].flg_nsd=flg_nsd;
 	} /* endif */
@@ -571,10 +575,10 @@ nco_ppc_bitmask /* [fnc] Mask-out insignificant bits of significand */
      "A common convention in science and engineering is to express accuracy and/or precision implicitly by means of significant figures. Here, when not explicitly stated, the margin of error is understood to be one-half the value of the last significant place. For instance, a recording of 843.6 m, or 843.0 m, or 800.0 m would imply a margin of 0.05 m (the last significant place is the tenths place), while a recording of 8,436 m would imply a margin of error of 0.5 m (the last significant digits are the units)." -- Wikipedia
      
      Test NSD:
-     nc3tonc4 -o --quantize=ppc_big=3,ppc_bgr=3,ppc_flt=3 --quiet=1 ~/nco/data/in.nc ~/foo_n34.nc
-     ncks -D 1 -4 -O -C -v ppc_big,ppc_bgr,ppc_flt --ppc .?=3 ~/nco/data/in.nc ~/foo.nc
-     ncks -C -v ppc_big,ppc_bgr ~/foo.nc
-     ncks -s '%16.12e\n' -C -H -v ppc_big,ppc_bgr ~/foo_n34.nc */
+     nc3tonc4 -o --quantize=ppc_big=3,ppc_btg=3,ppc_flt=3 --quiet=1 ~/nco/data/in.nc ~/foo_n34.nc
+     ncks -D 1 -4 -O -C -v ppc_big,ppc_btg,ppc_flt --ppc .?=3 ~/nco/data/in.nc ~/foo.nc
+     ncks -C -v ppc_big,ppc_btg ~/foo.nc
+     ncks -s '%16.12e\n' -C -H -v ppc_big,ppc_btg ~/foo_n34.nc */
   
   /* IEEE single- and double-precision significands have 24 and 53 bits of total precision (prc_bnr)
      Decimal digits of precision (prc_dcm) obtained via prc_dcm=prc_bnr*ln(2)/ln(10) = 7.22 and 15.95, respectively
@@ -661,7 +665,7 @@ nco_ppc_bitmask /* [fnc] Mask-out insignificant bits of significand */
   int bit_xpl_nbr_zro; /* [nbr] Number of explicit bits to zero */
   int prc_bnr_ceil; /* [nbr] Exact binary digits of precision rounded-up */
   int prc_bnr_xpl_rqr=int_CEWI; /* [nbr] Explicitly represented binary digits (i.e., keepbits) required to retain */
-  int nsb; /* I [nbr] Number of significant bits, i.e., "keepbits" */
+  int nesb; /* I [nbr] Number of explicit significant bits, i.e., "keepbits" */
 
   long idx;
 
@@ -683,7 +687,7 @@ nco_ppc_bitmask /* [fnc] Mask-out insignificant bits of significand */
 
   /* Step 1: Determine # keepbits for algorithms that use a uniform number 
      For NSD algorithms this involves using log2() math and some fine-tuning
-     For NSB algorithms this simply means sanity checking user input */
+     For NESB algorithms this simply means sanity checking user input */
   switch(nco_baa_cnv_typ){
     /* Methods that do granular pre-processing of NSD or masks */
   case nco_baa_dgr:
@@ -694,10 +698,10 @@ nco_ppc_bitmask /* [fnc] Mask-out insignificant bits of significand */
     prc_bnr_xpl_rqr=5;
     break;
     /* Methods that pre-process NSD to obtain keepbits, masks */
-  case nco_baa_bgr:
+  case nco_baa_btg:
   case nco_baa_shv:
   case nco_baa_set:
-  case nco_baa_bgr_btr:
+  case nco_baa_bgr:
   case nco_baa_brt:
     /* Most NCO lossy routines expect user to provide NSD */
     /* Disallow unreasonable quantization */
@@ -725,13 +729,13 @@ nco_ppc_bitmask /* [fnc] Mask-out insignificant bits of significand */
        ncra -4 -O -C --ppc default=1 --ppc one=1 -p ~/nco/data in.nc in.nc ~/foo.nc 
        ncks -H -v Q.. --cdl ~/foo.nc | m */
     break;
-    /* Methods that expect user to provide NSB not NSD */
+    /* Methods that expect user to provide NESB not NSD */
   case nco_baa_sh2:
   case nco_baa_btr:
-    nsb=nsd;
+    nesb=nsd;
     /* Disallow unreasonable quantization */
-    assert(nsb > 0);
-    prc_bnr_xpl_rqr=nsb;
+    assert(nesb > 0);
+    prc_bnr_xpl_rqr=nesb;
     break;
   default: 
     nco_dfl_case_generic_err();
@@ -769,11 +773,11 @@ nco_ppc_bitmask /* [fnc] Mask-out insignificant bits of significand */
   case nco_baa_gbr:
     /* These methods create masks within the loop over values */
     break;
-    /* Methods that use uniform NSD or NSB and masks */
-  case nco_baa_bgr:
+    /* Methods that use uniform NSD or NESB and masks */
+  case nco_baa_btg:
   case nco_baa_shv:
   case nco_baa_set:
-  case nco_baa_bgr_btr:
+  case nco_baa_bgr:
   case nco_baa_brt:
   case nco_baa_sh2:
   case nco_baa_btr:
@@ -806,7 +810,7 @@ nco_ppc_bitmask /* [fnc] Mask-out insignificant bits of significand */
   switch(type){
   case NC_FLOAT:
     switch(nco_baa_cnv_typ){
-    case nco_baa_bgr:
+    case nco_baa_btg:
       /* Bit-Groom: alternately shave and set LSBs */
       for(idx=0L;idx<sz;idx+=2L)
 	if(op1.fp[idx] != mss_val_cmp_flt) u32_ptr[idx]&=msk_f32_u32_zro;
@@ -814,7 +818,7 @@ nco_ppc_bitmask /* [fnc] Mask-out insignificant bits of significand */
 	if(op1.fp[idx] != mss_val_cmp_flt && u32_ptr[idx] != 0U) /* Never quantize upwards floating point values of zero */
 	  u32_ptr[idx]|=msk_f32_u32_one;
       break;
-      /* !BitGroom = BGR */
+      /* !BitGroom = BTG */
     case nco_baa_shv:
       /* Bit-Shave: always shave LSBs */
       for(idx=0L;idx<sz;idx++)
@@ -830,7 +834,7 @@ nco_ppc_bitmask /* [fnc] Mask-out insignificant bits of significand */
       /* Digit Rounding (DCG19)
 	 Test DGR:
 	 ccc --tst=bnr --flt_foo=8 2> /dev/null | grep "Binary of float"
-	 ncks -O -C -D 1 --baa=3 -v ppc_bgr --ppc default=3 ~/nco/data/in.nc ~/foo.nc
+	 ncks -O -C -D 1 --baa=3 -v ppc_btg --ppc default=3 ~/nco/data/in.nc ~/foo.nc
 	 ncks -O -C -D 1 --baa=3 -v one_dmn_rec_var_flt --ppc default=3 ~/nco/data/in.nc ~/foo.nc */
 
       /* 20210927:
@@ -932,7 +936,7 @@ nco_ppc_bitmask /* [fnc] Mask-out insignificant bits of significand */
       /* Granular BitGroom
 	 Test GBG:
 	 ccc --tst=bnr --flt_foo=8 2> /dev/null | grep "Binary of float"
-	 ncks -O -7 -C -D 1 --baa=4 -v ppc_bgr --ppc default=3 ~/nco/data/in.nc ~/foo.nc
+	 ncks -O -7 -C -D 1 --baa=4 -v ppc_btg --ppc default=3 ~/nco/data/in.nc ~/foo.nc
 	 ncks -O -7 -C -D 1 --baa=4 -v one_dmn_rec_var_flt --ppc default=3 ~/nco/data/in.nc ~/foo.nc */
       for(idx=0L;idx<sz;idx++){
 	if((val=op1.fp[idx]) != mss_val_cmp_flt && u32_ptr[idx] != 0U){
@@ -984,10 +988,10 @@ nco_ppc_bitmask /* [fnc] Mask-out insignificant bits of significand */
       } /* !idx */
       break;
       /* !GranularBitRound = GBG */
-    case nco_baa_bgr_btr:
+    case nco_baa_bgr:
     case nco_baa_btr:
       /* BitRound and
-	 BitGroom with BitRound (instead of shave/set):
+	 BitGroomRound (instead of shave/set):
 	 Round mantissa, LSBs to zero contributed by Rostislav Kouznetsov 20200711
 	 Round mantissa using IEEE floating-point arithmetic, shave LSB using bit-mask */
       for(idx=0L;idx<sz;idx++){
@@ -998,7 +1002,7 @@ nco_ppc_bitmask /* [fnc] Mask-out insignificant bits of significand */
       } /* !idx */
       break;
       /* !BitRound = BTR */
-      /* !BitGroomRound = RND */
+      /* !BitGroomRound = BGR */
     case nco_baa_sh2:
       /* Bit Half-Shave contributed by Rostislav Kouznetsov 20200715
 	 Shave LSBs and set MSB of them
@@ -1068,7 +1072,7 @@ nco_ppc_bitmask /* [fnc] Mask-out insignificant bits of significand */
     break; /* !NC_FLOAT */
   case NC_DOUBLE:
     switch(nco_baa_cnv_typ){
-    case nco_baa_bgr:
+    case nco_baa_btg:
       /* Bit-Groom: alternately shave and set LSBs */
       for(idx=0L;idx<sz;idx+=2L)
 	if(op1.dp[idx] != mss_val_cmp_dbl)
@@ -1156,7 +1160,7 @@ nco_ppc_bitmask /* [fnc] Mask-out insignificant bits of significand */
       } /* !idx */
       break;
       /* !GranularBitRound = GBG */
-    case nco_baa_bgr_btr:
+    case nco_baa_bgr:
     case nco_baa_btr:
       /* Round mantissa, LSBs to zero contributed by Rostislav Kouznetsov 20200711
 	 Round mantissa using software emulation of IEEE arithmetic, shave LSB using bit-mask
@@ -1169,7 +1173,7 @@ nco_ppc_bitmask /* [fnc] Mask-out insignificant bits of significand */
       } /* !idx */
       break;
       /* !BitRound = BTR */
-      /* !BitGroomRound = RND */
+      /* !BitGroomRound = BGR */
     case nco_baa_sh2:
       /* Bit Half-Shave contributed by Rostislav Kouznetsov 20200715
 	 Shave LSBs and set MSB of them
