@@ -134,7 +134,7 @@ cvs_vrs_prs(void) /* [fnc] Return CVS version string */
     (void)fprintf(stderr,"cvs_mjr_vrs %li\n",cvs_mjr_vrs);
     (void)fprintf(stderr,"cvs_mnr_vrs %li\n",cvs_mnr_vrs);
     (void)fprintf(stderr,"cvs_pch_vrs %li\n",cvs_pch_vrs);
-  } /* endif dbg */
+  } /* !dbg */
 
   cvs_mjr_vrs_sng=(char *)nco_free(cvs_mjr_vrs_sng);
   cvs_mnr_vrs_sng=(char *)nco_free(cvs_mnr_vrs_sng);
@@ -148,7 +148,7 @@ void
 nco_cpy_prn(void) /* [fnc] Print copyright notice */
 {
   /* Purpose: Print copyright notice */
-  (void)fprintf(stderr,"Copyright (C) 1995--2022 Charlie Zender\n");
+  (void)fprintf(stderr,"Copyright (C) 1995--2023 Charlie Zender\n");
   (void)fprintf(stdout,"This program is part of NCO, the netCDF Operators.\nNCO is free software and comes with a BIG FAT KISS and ABSOLUTELY NO WARRANTY\nYou may redistribute and/or modify NCO under the terms of the\n3-Clause BSD License with exceptions described in the LICENSE file\nBSD: https://opensource.org/licenses/BSD-3-Clause\nLICENSE: https://github.com/nco/nco/tree/master/LICENSE\n");
 } /* end copyright_prn() */
 
@@ -208,7 +208,7 @@ nco_nmn_get(void) /* [fnc] Return mnemonic that describes current NCO version */
   /* Purpose: Return mnemonic describing current NCO version
      20191221: ncremap/ncclimo print left quote and first word of this string, so one-word strings look best 
      20200117: fixed this limitation, multi-word versions work fine */
-  return "Mauna Loa";
+  return "Bakhmut";
 } /* !nco_nmn_get() */
 
 void
