@@ -51,7 +51,7 @@ nco_trr_ini /* [fnc] Initialize Terraref structure */
     (void)fprintf(stderr,"fl_out = %s, ",trr->fl_out ? trr->fl_out : "NULL");
     (void)fprintf(stderr,"fl_out_tmp = %s, ",trr->fl_out_tmp ? trr->fl_out_tmp : "NULL");
     (void)fprintf(stderr,"\n");
-  } /* endif dbg */
+  } /* !dbg */
   
   /* Parse extended kvm options */
   int trr_var_idx; /* [idx] Index over trr_lst (i.e., all names explicitly specified in all "--trr var1[,var2]=val" options) */
@@ -244,7 +244,6 @@ nco_trr_read /* [fnc] Read, parse, and print contents of TERRAREF file */
   int dmn_id_wvl; /* [id] Wavelength dimension ID */
   int dmn_id_xdm; /* [id] X-dimension ID */
   int dmn_id_ydm; /* [id] Y-dimension ID */
-  int dfl_lvl; /* [enm] Deflate level [0..9] */
   /* Terraref raw image files can be ~64 GB large so use netCDF4 */
   int fl_out_fmt=NC_FORMAT_NETCDF4; /* [enm] Output file format */
   int out_id; /* I [id] Output netCDF file ID */
@@ -298,12 +297,10 @@ nco_trr_read /* [fnc] Read, parse, and print contents of TERRAREF file */
   var_typ_in=trr->var_typ_in; /* [enm] NetCDF type-equivalent of binary data (raw imagery) */
   var_typ_out=trr->var_typ_out; /* [enm] NetCDF type of data in output file */
 
-  dfl_lvl=trr->dfl_lvl;
-
   if(nco_dbg_lvl_get() >= nco_dbg_std){
     (void)fprintf(stderr,"%s: INFO %s Terraref metadata: ",nco_prg_nm_get(),fnc_nm);
     (void)fprintf(stderr,"wvl_nbr = %li, xdm_nbr = %li, ydm_nbr = %li, ntl_typ_in = %s, ntl_typ_out = %s, var_typ_in = %s, var_typ_out = %s\n",wvl_nbr,xdm_nbr,ydm_nbr,nco_trr_ntl_sng(ntl_typ_in),nco_trr_ntl_sng(ntl_typ_out),nco_typ_sng(var_typ_in),nco_typ_sng(var_typ_out));
-  } /* endif dbg */
+  } /* !dbg */
 
   var_sz=wvl_nbr*xdm_nbr*ydm_nbr;
   var_val.vp=(void *)nco_malloc(var_sz*nctypelen(var_typ_in));
@@ -408,14 +405,7 @@ nco_trr_read /* [fnc] Read, parse, and print contents of TERRAREF file */
   dmn_cnt[dmn_idx_ydm]=ydm_nbr;
 
   (void)nco_def_var(out_id,var_nm,var_typ_out,dmn_nbr_3D,dmn_ids,&var_id);
-
-  if(dfl_lvl > 0){
-    int shuffle; /* [flg] Turn-on shuffle filter */
-    int deflate; /* [flg] Turn-on deflate filter */
-    deflate=(int)True;
-    shuffle=NC_SHUFFLE;
-    (void)nco_def_var_deflate(out_id,var_id,shuffle,deflate,dfl_lvl);
-  } /* !dfl_lvl */
+  if(nco_cmp_glb_get()) rcd+=nco_flt_def_out(out_id,var_id,NULL,nco_flt_flg_nil);
   
   /* Define "units" attributes */
   rcd=nco_char_att_put(out_id,NULL,"title",trr->ttl);
@@ -922,7 +912,7 @@ nco_rgr_esmf /* [fnc] Regrid using ESMF library */
     (void)fprintf(stderr,"ESMC_GridAddCoord(): stg_lcn_src = %s,  stg_lcn_dst = %s\n",nco_esmf_stg_lcn_sng(stg_lcn_src),nco_esmf_stg_lcn_sng(stg_lcn_dst));
     (void)fprintf(stderr,"ESMC_GridGetCoord(): bnd_lwr_src[0..1] = %d, %d; bnd_upr_src[0..1] = %d, %d;\n",bnd_lwr_src[0],bnd_lwr_src[1],bnd_upr_src[0],bnd_upr_src[1]);
     //    (void)fprintf(stderr,"ESMC_InterfaceIntCreate(): max_idx_src[0..1] = %d, %d\n",max_idx_src[0],max_idx_src[1]);
-  } /* endif dbg */
+  } /* !dbg */
 
   /* Type-conversion and cell-center coordinates */
   for(idx=0;idx<bnd_upr_src[crd_idx_f_0bs_lat_src];idx++) lat_src[idx]=lat_in[idx];
@@ -1351,7 +1341,7 @@ nco_rgr_esmf2 /* [fnc] Regrid using ESMF library */
     (void)fprintf(stderr,"ESMC_GridAddCoord(): stg_lcn_src = %s,  stg_lcn_dst = %s\n",nco_esmf_stg_lcn_sng(stg_lcn_src),nco_esmf_stg_lcn_sng(stg_lcn_dst));
     (void)fprintf(stderr,"ESMC_GridGetCoord(): bnd_lwr_src[0..1] = %d, %d; bnd_upr_src[0..1] = %d, %d;\n",bnd_lwr_src[0],bnd_lwr_src[1],bnd_upr_src[0],bnd_upr_src[1]);
     //    (void)fprintf(stderr,"ESMC_InterfaceIntCreate(): max_idx_src[0..1] = %d, %d\n",max_idx_src[0],max_idx_src[1]);
-  } /* endif dbg */
+  } /* !dbg */
 
   /* Type-conversion and cell-center coordinates */
   for(idx=0;idx<bnd_upr_src[crd_idx_f_0bs_lat_src];idx++) lat_src[idx]=lat_in[idx];
