@@ -20,14 +20,14 @@
 /* Standard header files */
 #include <assert.h> /* assert() */
 #include <stdio.h> /* stderr, FILE, NULL, printf */
-#include <stdlib.h> /* strtod, strtol, malloc, getopt, exit */
+#include <stdlib.h> /* strtod, strtol, malloc, getopt, exit, mkstemp */
 #include <string.h> /* strcmp() */
 
 #ifdef HAVE_REGEX_H 
 /* 20120213: Linux GCC 4.6 man page says regex.h depends on (non-present) sys/types.h */
-# ifdef MACOSX
+# ifdef MACOS
 #  include <sys/types.h> /*19950312: _res, 20040822: Mac OS X off_t required by regex.h */
-# endif /* !MACOSX */
+# endif /* !MACOS */
 # include <regex.h> /* POSIX regular expressions library */
 #endif /* HAVE_REGEX_H */
 
